<?php
/**
 * Canuck Home Page template part - full slider - carousel navigation
 *
 * This template part is called by canuck_home_feature_options()
 * located in canuck-custom-functions.php
 *
 * @package     Canuck WordPress Theme
 * @copyright   Copyright (C) 2020 or later Kevin Archibald
 * @license     http://www.gnu.org/licenses/gpl-2.0.html
 * @author      Kevin Archibald <www.kevinsspace.ca/contact/>
 */

global $post, $canuck_feature_option, $canuck_feature_category;
$canuck_effect = sanitize_text_field( get_theme_mod( 'canuck_flex_slider_effect', 'fade' ) );
$canuck_pause  = sanitize_text_field( get_theme_mod( 'canuck_flex_slider_pause', '5000' ) );
$canuck_trans  = sanitize_text_field( get_theme_mod( 'canuck_flex_slider_trans', '600' ) );
$canuck_auto   = intval( get_theme_mod( 'canuck_flex_slider_auto', 1 ) );
$category_id   = get_cat_ID( $canuck_feature_category );
$args          = array(
	'category'    => $category_id,
	'numberposts' => 20,
);
$custom_posts  = get_posts( $args );
$use_lazyload  = get_theme_mod( 'canuck_use_lazyload' ) ? true : false;
if ( 0 !== $category_id && $custom_posts ) {
	?>
	<div id="canuck-feature-15to1-id" class="splide canuck-feature-15to1" data-splide=<?php echo '{"type":"' . esc_attr( $canuck_effect ) . '","arrows":1,"rewind":1,"interval":' . intval( $canuck_pause ) . ',"speed":' . intval( $canuck_trans ) . ',"autoplay":' . esc_attr( $canuck_auto ) . '}'; ?>>
	<div class="splide__track">
			<ul class="splide__list">
				<?php
				$canuck_feature_pic_count = 0;
				foreach ( $custom_posts as $post ) { // phpcs:ignore
					setup_postdata( $post );
					$link_to_post          = ( '' === get_post_meta( $post->ID, 'canuck_metabox_link_to_post', true ) ? false : true );
					$custom_feature_link   = ( '' === get_post_meta( $post->ID, 'canuck_custom_feature_link', true ) ? false : get_post_meta( $post->ID, 'canuck_custom_feature_link', true ) );
					$include_feature_title = ( '' === get_post_meta( $post->ID, 'canuck_metabox_include_feature_title', true ) ? false : true );
					if ( has_post_thumbnail() ) {
						$canuck_feature_pic_count ++;
						?>
						<li class="splide__slide">
							<?php
							$image_url            = get_the_post_thumbnail_url( $post->ID, 'canuck_med15' );
							$canuck_feature_title = false === $include_feature_title ? get_post( get_post_thumbnail_id() )->post_excerpt : the_title_attribute( 'echo=0' );
							if ( '' === $canuck_feature_title ) {
								$imagetitle = '';
								$imagealt   = esc_html__( 'flexslider image', 'canuck' );
							} else {
								$imagetitle = $canuck_feature_title;
								$imagealt   = $canuck_feature_title;
							}
							if ( true === $include_feature_title ) {
								if ( '' !== $canuck_feature_title ) {
									echo '<p class="splide-caption">' . wp_kses_post( $canuck_feature_title ) . '</p>';
								}
							}
							// Set up the link and image.
							if ( true === $link_to_post ) {
								?>
								<a href="<?php echo esc_url( get_permalink() ); ?>" title="<?php echo the_title_attribute( 'echo=0' ); ?>">
									<img src="<?php echo esc_url( $image_url ); ?>"
										title="<?php echo esc_attr( $imagetitle ); ?>" alt="<?php echo esc_attr( $imagealt ); ?>" />
								</a>
								<?php
							} elseif ( false !== $custom_feature_link ) {
								?>
								<a href="<?php echo esc_url( $custom_feature_link ); ?>" title="<?php echo the_title_attribute( 'echo=0' ); ?>">
									<img src="<?php echo esc_url( $image_url ); ?>"
										title="<?php echo esc_attr( $imagetitle ); ?>" alt="<?php echo esc_attr( $imagealt ); ?>" />
								</a>
								<?php
							} else {
								?>
								<img src="<?php echo esc_url( $image_url ); ?>"
									title="<?php echo esc_attr( $imagetitle ); ?>" alt="<?php echo esc_attr( $canuck_feature_title ); ?>" />
								<?php
							}
							?>
						</li>
						<?php
					}
				}
				?>
			</ul>
		</div>
	</div>
	<?php
} else {
	?>
	<div class="error">esc_html_e( 'You have not set up your Feature posts so I can not find any images - see user documentation.', 'canuck' ); ?></div>
	<?php
}
if ( 0 === $canuck_feature_pic_count ) {
	?>
	<div class="error">
		<h3><?php esc_html_e( 'Error: There were no feature images found for your slider. Did you select the correct category?', 'canuck' ); ?></h3>
	</div>
	<?php
}
wp_reset_postdata();

